
#import "GameBoardView.h"


@implementation GameBoardView

@synthesize	bgImage;
@synthesize	delegate;

////////////////////////////////////////////////////////
//初期化
////////////////////////////////////////////////////////
- (id)initWithFrame:(CGRect)frame Tiles:(NSArray*)tiles BGImage:(UIImage*)image{
	
    if (self = [super initWithFrame:frame]) {
		//タイル
		tileArray = [tiles retain];
		//背景イメージの設定とCGレイヤーのアップデート
		self.bgImage = image;
    }
	
    return self;
}


////////////////////////////////////////////////////////
//描画
////////////////////////////////////////////////////////
- (void)drawRect:(CGRect)rect {
	
	[self.bgImage drawInRect:self.bounds blendMode:kCGBlendModeNormal alpha:1.0];
	
	//タイルを描画する
	CGContextRef	context = UIGraphicsGetCurrentContext();
	int	i;
	GameBoardTile	*tile;
	for (i=0; i < [tileArray count]; i++) {
		tile = [tileArray objectAtIndex:i];
		[tile drawTile:context];
	}
}

////////////////////////////////////////////////////////
//解放
////////////////////////////////////////////////////////
- (void)dealloc {
	[bgImage release];
    [super dealloc];
}

////////////////////////////////////////////////////////
//指定位置のタイルを返す
////////////////////////////////////////////////////////
-(GameBoardTile*) tileAtPoint:(CGPoint)pt
{
	int				i;
	GameBoardTile	*tile;
	for (i=0; i < [tileArray count]; i++) {
		tile = [tileArray objectAtIndex:i];
		if( [tile tileCheck:pt] ){
			return	tile;
		}
	}
	return	nil;
}

////////////////////////////////////////////////////////
// 指定のタイルを返す
////////////////////////////////////////////////////////
-(GameBoardTile*)tileAtIndex:(int)index
{
	if([tileArray count] > index && index >= 0 )
		return	[tileArray objectAtIndex:index];
	else
		return	nil;
}

#pragma mark -

////////////////////////////////////////////////////////
// スクリーンがタッチされた
////////////////////////////////////////////////////////
- (void) touchesBegan:(NSSet*)touches withEvent:(UIEvent*)event
{
	NSSet*		allTouchs = [event allTouches];
	UITouch*	touch = [allTouchs anyObject];
	NSUInteger	taps = [touch tapCount];
	CGPoint		location = [touch locationInView:self];
	
	//デリゲートメソッド
	if( [delegate respondsToSelector:@selector(gameBoardViewTouchDown:Location:Taps:Event:)]){
		[delegate gameBoardViewTouchDown:self Location:location Taps:taps Event:event];
	}
}

////////////////////////////////////////////////////////
// スクリーンがタッチされた指が移動
////////////////////////////////////////////////////////
- (void) touchesMoved:(NSSet*)touches withEvent:(UIEvent*)event
{
	NSSet*		allTouchs = [event allTouches];
	UITouch*	touch = [allTouchs anyObject];
	NSUInteger	taps = [touch tapCount];
	CGPoint		location = [touch locationInView:self];
	
	//デリゲートメソッド
	if( [delegate respondsToSelector:@selector(gameBoardViewTouchMove:Location:Taps:Event:)]){
		[delegate gameBoardViewTouchMove:self Location:location Taps:taps Event:event];
	}
}

////////////////////////////////////////////////////////
// スクリーンがタッチされた指が離れた
////////////////////////////////////////////////////////
- (void) touchesEnded:(NSSet*)touches withEvent:(UIEvent*)event
{
	NSSet*		allTouchs = [event allTouches];
	UITouch*	touch = [allTouchs anyObject];
	NSUInteger	taps = [touch tapCount];
	CGPoint		location = [touch locationInView:self];
	
	//デリゲートメソッド
	if( [delegate respondsToSelector:@selector(gameBoardViewTouchUp:Location:Taps:Event:)]){
		[delegate gameBoardViewTouchUp:self Location:location Taps:taps Event:event];
	}
}



@end
