
#import <QuartzCore/QuartzCore.h>
#import "GameController.h"
#import "GameBoardView.h"
#import "GameBoardTile.h"
#import "GamePieceView.h"


@implementation GameController

@synthesize	gameView;

////////////////////////////////////////////////////////
//初期化
////////////////////////////////////////////////////////
- (id) initWithBaseView:(UIView*)baseview
{
	self = [super init];
	if (self != nil) {
		
		//ゲームビュー生成
		NSMutableArray*		tileArray = [NSMutableArray array];
		CGRect	rect[4]={
			{ 40,  30, TILE_WIDTH, TILE_HEIGHT},
			{220,  30, TILE_WIDTH, TILE_HEIGHT},
			{ 40, 220, TILE_WIDTH, TILE_HEIGHT},
			{220, 220, TILE_WIDTH, TILE_HEIGHT}
		};
		for (int i=0; i < 4; i++) {
			CGRect	frame = rect[i];
			GameBoardTile*	tile = [GameBoardTile gameBoardTileWith:frame State:0];
			tile.contentImage = [UIImage imageNamed:@"TileImage.png"];
			tile.tileIndex = i;
			[tileArray addObject:tile];
		}
		self.gameView = [[[GameBoardView alloc] initWithFrame:CGRectMake(0, 0, baseview.frame.size.width, baseview.frame.size.height) 
															  Tiles:tileArray 
															BGImage:[UIImage imageNamed:@"bg00.png"]] autorelease];
		[baseview addSubview:self.gameView];
		self.gameView.delegate = self;
		
		//駒を生成
		NSArray*	array = [NSArray arrayWithObjects:[UIImage imageNamed:@"PieceImage.png"], nil];
		pieceView = [[GamePieceView alloc] initWithFrame:CGRectMake(0, 0, 48, 48) Images:array Delegate:self];
		//配置
		[gameView addSubview:pieceView];
		GameBoardTile*	tile = [self.gameView tileAtIndex:0];
		tile.piece = pieceView;
		pieceView.tile = tile;
		pieceView.center = [tile center];
	}
	
	return	self;
}

////////////////////////////////////////////////////////
//解放
////////////////////////////////////////////////////////
- (void)dealloc {
	[pieceView release];
	[gameView release];
    [super dealloc];
}


#pragma mark -
#pragma mark -- GameBoardViewDelegate --

////////////////////////////////////////////////////////
//タッチアップ
////////////////////////////////////////////////////////
-(void) gameBoardViewTouchUp:(GameBoardView*)gmView Location:(CGPoint)touchPt Taps:(int)taps Event:(UIEvent*)event
{
	GameBoardTile*	tile = [gmView tileAtPoint:touchPt];
	if( tile && isPieceMoveing==NO){
		[pieceView moveWith:tile];
	}

}


#pragma mark -
#pragma mark -- GamePieceViewDelegate --

////////////////////////////////////////////////////////
//スタート
////////////////////////////////////////////////////////
-(void) gamePieceCAMoveStart:(GamePieceView*)piece Position:(CGPoint)pt
{
	isPieceMoveing = YES;
}

////////////////////////////////////////////////////////
//停止
////////////////////////////////////////////////////////
-(void) gamePieceCAMoveEnd:(GamePieceView*)piece Position:(CGPoint)pt Finish:(BOOL)isFinish
{
	isPieceMoveing = NO;
}




@end
