
#import <QuartzCore/QuartzCore.h>
#import <math.h>
#import "GamePieceView.h"
#import "GameBoardTile.h"


@implementation GamePieceView

@synthesize	delegate;
@synthesize	imageArray;
@synthesize	imageIndex;
@synthesize	speed;
@synthesize	isMoveing;
@synthesize	tile;

////////////////////////////////////////////////////////
//初期化
////////////////////////////////////////////////////////

-(id)initWithFrame:(CGRect)frame Images:(NSArray*)images Delegate:(id)del
{
	if (self = [super initWithFrame:frame]) {
		self.opaque = NO;
		imageIndex = 0;
		speed = 200;
		self.imageArray = images;
		self.delegate = del;
	}
	return self;
}



////////////////////////////////////////////////////////
//解放
////////////////////////////////////////////////////////
- (void)dealloc {
	[imageArray release];
	[tile release];
	[super dealloc];
}


////////////////////////////////////////////////////////
//描画
////////////////////////////////////////////////////////
- (void)drawRect:(CGRect)rect {
	
	if( [imageArray count] ){
		UIImage*	image = [imageArray objectAtIndex:imageIndex];
		[image drawInRect:rect blendMode:kCGBlendModeNormal alpha:1.0];
	}
}


#pragma mark -

////////////////////////////////////////////////////////
//移動タイル設定
////////////////////////////////////////////////////////
-(void)moveWith:(GameBoardTile*)movTile
{
	if(tile!=movTile){
		self.tile = movTile;
		self.tile.piece = self;
		[self movePosition:[self.tile center]];
	}
}


////////////////////////////////////////////////////////
//位置移動
////////////////////////////////////////////////////////
-(void)movePosition:(CGPoint)toPoint
{
	moveLocation = toPoint;
	//位置移動のためのアニメーションクラス
	CABasicAnimation*	anime = [CABasicAnimation animationWithKeyPath:@"position"];
	CGPoint	fromPt = self.layer.position;
	
	//移動２点間の距離を求め移動時間を求める
	double	x = fabs(toPoint.x-fromPt.x);
	double	y = fabs(toPoint.y-fromPt.y);
	double	moveLen = sqrt((x*x)+(y*y));
	anime.duration = moveLen / speed;
	//移動の始点
	anime.fromValue = [NSValue valueWithCGPoint:fromPt];
	//移動の終点
	anime.toValue = [NSValue valueWithCGPoint:toPoint];		
	
	//アニメーションをレイヤーに設定
	isMoveing = YES;
	anime.delegate = self;
	[self.layer addAnimation:anime forKey:@"animatePosition"];
	
	//移動先に移動させる
	CGRect			aFrame = [self frame];
	CGPoint			nowPt = toPoint;
	[self.layer setFrame:CGRectMake(nowPt.x-(aFrame.size.width/2), nowPt.y-(aFrame.size.height/2), aFrame.size.width, aFrame.size.height)];
}

-(void)moveCancelPosition
{
	[self.layer removeAnimationForKey:@"animatePosition"];
	CALayer*	layer = [[self layer] presentationLayer];
	CGPoint		pt = layer.position;
	self.center = pt;
}


#pragma mark -
#pragma mark -- CAAnimationDelegate --

- (void)animationDidStart:(CAAnimation *)theAnimation
{
	//デリゲートメソッド
	if( [delegate respondsToSelector:@selector(gamePieceCAMoveStart:Position:)]){
		CALayer*	layer = [[self layer] presentationLayer];
		CGPoint		pt = layer.position;
		[delegate gamePieceCAMoveStart:self Position:pt];
	}
}

- (void)animationDidStop:(CAAnimation *)theAnimation finished:(BOOL)flag
{
	isMoveing = NO;
	//デリゲートメソッド
	if( [delegate respondsToSelector:@selector(gamePieceCAMoveEnd:Position:Finish:)]){
		CALayer*	layer = [[self layer] presentationLayer];
		CGPoint		pt = layer.position;
		[delegate gamePieceCAMoveEnd:self Position:pt Finish:flag];
	}
}




@end
